# -*- coding:utf-8 -*-


class RestSqlMiddleware(object):

    def __init__(self):
        pass

    @staticmethod
    def process_query(query):
        '''
        :param query: restsql query
        '''
        raise NotImplementedError("Please overwrite this method")


# -*- coding:utf-8 -*-
from peewee import ModelBase, TextField, DoubleField, BooleanField, IntegerField
from table import Table, StringField, NumberField, IntegerField, BoolField
from copy import deepcopy


class ModelMeta(ModelBase):

    def __new__(mcs, name, bases, attrs):
        base_attrs = deepcopy(attrs)
        meta = base_attrs.get('Meta', None)
        for field, field_type in meta.fields.items():
            if isinstance(field_type, StringField):
                base_attrs[field] = TextField()
            elif isinstance(field_type, NumberField):
                base_attrs[field] = DoubleField()
            elif isinstance(field_type, IntegerField):
                base_attrs[field] = IntegerField()
            elif isinstance(field_type, BoolField):
                base_attrs[field] = BooleanField()
        del meta.fields  # 删除该类属性，否则进入base.new中fields属性会产生冲突
        return super(ModelMeta, mcs).__new__(mcs, name, bases, base_attrs)


# def gen_model(db, schema):
#     if not isinstance(db, Database):
#         raise RuntimeError('db is not Database instance')
#     if schema.__bases__[0] != Schema:
#         raise RuntimeError('schema is not Schema class')
#
#     class NewModel(Model):
#         __metaclass__ = ModelMeta
#
#         class Meta:
#             database = db
#             table_name = schema.table_name
#             fields = schema.fields
#     return NewModel


class User(Table):
    table_name = 'user'
    fields = {
        'version': NumberField(),
        'login': StringField(),
        'email': StringField()
    }










# -*- coding:utf-8 -*-

from middleware import RestSqlMiddleware
from restsql import RestSqlClient
from restsqldb import EnumDataBase
from table import Table, NumberField, StringField, BoolField, IntegerField


# -*- coding:utf-8 -*-


class Field(object):
    pass


class IntegerField(Field):
    '''
    整数类型
    '''
    pass


class NumberField(Field):
    '''
    数字类型
    '''
    pass


class StringField(Field):
    '''
    字符串类型
    '''
    pass


class BoolField(Field):
    '''
    布尔类型
    '''
    pass


class Table(object):
    '''
    Schema基类
    '''

    pass





#! /usr/bin/env python
# -*- coding: utf-8 -*-
import setuptools

setuptools.setup(
    name='restsql',
    version='0.1.6',
    author="venzozhang",
    packages=setuptools.find_packages(),
    license='All right reserved',
    long_description="restsql",
    install_requires=[
        'certifi==2019.9.11',
        'chardet==3.0.4',
        'elasticsearch==5.4.0',
        'elasticsearch-dsl==5.3.0',
        'guppy==0.1.10',
        'idna==2.8',
        'ipaddress==1.0.23',
        'mysqlclient==1.4.2.post1',
        'numpy==1.16.5',
        'pandas==0.24.2',
        'psycopg2-binary==2.8.4',
        'pycrypto==2.6.1',
        'python-dateutil==2.8.0',
        'pytz==2019.2',
        'requests==2.22.0',
        'six==1.12.0',
        'urllib3==1.25.6',
        'peewee==3.13.2'
    ],
    classifiers=[
        "Programming Language :: Python",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)